@@ -5,13 +5,15 @@ import base64
 import random
 import pickle
 from sout import sout
+from relpath import rel2abs
 from fileinit import fileinit
 from .parts.AES_crypt import AESCipher
 
 revived_file_dir = "./__tskr_revived__/"
 
-with open("file_pool_path.txt", "r", encoding = "utf-8") as f:
-	file_pool_dir = f.read().strip()
+file_pool_dir = "./file_pool/"
+# with open(rel2abs("./file_pool_path.txt"), "r", encoding = "utf-8") as f:
+# 	file_pool_dir = f.read().strip()
 
 # 16進数の乱数を生成
 def gen_16_rand(n):
